<?php

namespace Drupal\search_api_decoupled_autocomplete\Plugin\search_ui_element;

use Drupal\Core\Form\FormStateInterface;
use Drupal\search_api_decoupled_ui\ConfigurableSearchUiElementBase;

/**
 * Plugin for Search UI Element "Autocomplete".
 *
 * @SearchUiElement(
 *   id = "autocomplete",
 *   label = @Translation("Autocomplete Search Input"),
 * )
 */
class Autocomplete extends ConfigurableSearchUiElementBase {

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [
      'placeholder' => $this->t('Search for contents'),
    ] + parent::defaultConfiguration();
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildConfigurationForm($form, $form_state);
    /** @var \Drupal\search_api_decoupled_ui\SearchApiEndpointUiInterface $search_api_endpoint */
    $search_api_endpoint = $form_state->get('search_api_endpoint');
    $autocomplete = $search_api_endpoint->getAutocomplete();
    if (empty($autocomplete)) {
      $form['#markup'] = $this->t('Autocomplete is not enabled for this endpoint.');
      return $form;
    }
    $form['placeholder'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Placeholder'),
      '#default_value' => $this->configuration['placeholder'],
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    parent::submitConfigurationForm($form, $form_state);
    $this->configuration['placeholder'] = $form_state->getValue('placeholder');
  }

  /**
   * {@inheritdoc}
   */
  public function getSummary() {
    return [
      '#markup' => $this->t('Placeholder: @placeholder.',
        [
          '@placeholder' => $this->configuration['placeholder'],
        ]),
    ];
  }

}
